@@ -1,9 +1,10 @@
-;;; $Id: irchat-200.el,v 1.1 1995/01/15 11:43:37 tmo Exp $
+;;;  -*- emacs-lisp -*-
+;;;
+;;;  $Id: irchat-200.el,v 1.2 1997/02/18 12:31:25 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile
-  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines))
+(eval-when-compile (require 'irchat-inlines))
 
 ;;;
 ;;;  200 replies
