@@ -1,9 +1,10 @@
-;;; $Id: irchat-300.el,v 1.1 1995/01/15 11:43:37 tmo Exp tmo $
+;;;  -*- emacs-lisp -*-
+;;;
+;;;  $Id: irchat-300.el,v 1.4 1997/02/18 12:31:25 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile
-  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines))
+(eval-when-compile (require 'irchat-inlines))
 
 ;;;
 ;;; 300 replies
@@ -55,7 +56,8 @@ This is called if no specific handler exists"
 	  (away (matching-substring rest 3))
 	  (who (matching-substring rest 4)))
       (irchat-w-insert irchat-300-buffer 
-		       (format "Nick %s is %s [%s, %s]\n"
+		       (format "%sNick %s is %s [%s, %s]\n"
+			       irchat-info-prefix
 			       nick who 
 			       (concat 
 				(if (string= oper "")
@@ -73,9 +75,11 @@ This is called if no specific handler exists"
   (if (string-match "[^ ]+ :\\(.*\\)" rest)
       (if (string= (matching-substring rest 1) "")
 	  (irchat-w-insert irchat-300-buffer 
-			   "No one you requested is on now.\n")
+			   (format "%sNo one you requested is on now.\n"
+				   irchat-info-prefix))
 	(irchat-w-insert irchat-300-buffer 
-			 (format "Following people(s) are on: %s\n"
+			 (format "%sFollowing people(s) are on: %s\n"
+				 irchat-info-prefix
 				 (matching-substring rest 1))))
     (irchat-w-insert irchat-300-buffer "IRCHAT: Strange 303 reply")))
 
@@ -122,7 +126,8 @@ This is called if no specific handler exists"
 	    (realname (matching-substring rest 5)))
 	(if (not irchat-recursing-whois)
 	 (irchat-w-insert irchat-300-buffer 
-			  (format "%s is %s (%s) at %s\n" 
+			  (format "%s%s is %s (%s) at %s\n"
+				  irchat-info-prefix
 				  nick username realname machine))))
     (irchat-w-insert irchat-300-buffer "IRCHAT: Strange 311 reply")))
 
@@ -142,7 +147,8 @@ This is called if no specific handler exists"
 	  (progn
 	    (setq irchat-recursing-whois nil)
 	    (irchat-w-insert irchat-300-buffer 
-			     (format "on via server %s (%s)\n" server real)))))
+			     (format "%son via server %s (%s)\n"
+				     irchat-info-prefix server real)))))
     (irchat-w-insert irchat-300-buffer "IRCHAT: Strange 312 reply")))
 
 
@@ -153,7 +159,8 @@ This is called if no specific handler exists"
 	    (iswhat (matching-substring rest 2)))
 	(if (not irchat-recursing-whois)
 	     (irchat-w-insert irchat-300-buffer 
-			      (format "STATUS: %s\n" iswhat))))
+			      (format "%sSTATUS: %s\n"
+				      irchat-info-prefix iswhat))))
     (irchat-w-insert irchat-300-buffer "IRCHAT: Strange 313 reply")))
 
 
@@ -170,7 +177,8 @@ This is called if no specific handler exists"
 	      (iswhat (matching-substring rest 3)))
 	  (if (not irchat-recursing-whois)
 	       (irchat-w-insert irchat-300-buffer 
-				(format "STATUS: %s\n" iswhat))))
+				(format "%sSTATUS: %s\n"
+					irchat-info-prefix iswhat))))
       (irchat-w-insert irchat-300-buffer "IRCHAT: Strange 316 reply"))))
 
 
@@ -180,7 +188,9 @@ This is called if no specific handler exists"
       (let ((who (matching-substring rest 2))
 	    (isonchannels (matching-substring rest 3)))
 	(if (not irchat-recursing-whois)
-	    (irchat-w-insert irchat-300-buffer (format "channels: %s\n" isonchannels))))))
+	    (irchat-w-insert irchat-300-buffer
+			     (format "%schannels: %s\n"
+				     irchat-info-prefix isonchannels))))))
 
 
 (defun irchat-handle-314-msg (prefix rest)
@@ -193,7 +203,8 @@ This is called if no specific handler exists"
 	    (realname (matching-substring rest 5)))
 	(message "")
 	(setq irchat-recursing-whowas t)
-	(irchat-w-insert irchat-300-buffer (format "%s [%s] was %s (%s) at %s\n"
+	(irchat-w-insert irchat-300-buffer (format "%s%s [%s] was %s (%s) at %s\n"
+			irchat-info-prefix
 			nick
 			(if (string= channel "*") "Priv" channel)
 			username
@@ -210,11 +221,11 @@ This is called if no specific handler exists"
 (defun irchat-handle-317-msg (prefix rest)
   "Handle the 317 WHOISIDLE."
   (if (string-match "^[^ ]+ [^ ]+ \\([0-9]*\\) :\\(.*\\)" rest)
-      (irchat-w-insert irchat-300-buffer (format "IDLE for %s\n" (irchat-convert-seconds 
-				       (matching-substring rest 1))))
+      (irchat-w-insert irchat-300-buffer (format "%sIDLE for %s\n" irchat-info-prefix 
+		(irchat-convert-seconds (matching-substring rest 1))))
     (if (string-match "^[^ ]+ \\([0-9]*\\) :\\(.*\\)" rest)
-	(irchat-w-insert irchat-300-buffer (format "IDLE for %s\n" (irchat-convert-seconds 
-					 (matching-substring rest 1))))
+	(irchat-w-insert irchat-300-buffer (format "%sIDLE for %s\n" irchat-info-prefix
+		(irchat-convert-seconds (matching-substring rest 1))))
       (if (string-match ; maybe older 2.6 or 2.5 server?
 	   "^\\([^ ]+\\) \\([^ ]+\\) \\([^ ]+\\) +\\([^ ]+\\) \\([^ ]+\\) \\([^ ]+\\) :\\(.*\\)"
 	   rest)
@@ -223,7 +234,7 @@ This is called if no specific handler exists"
 		(date (matching-substring rest 4))
 		(time (matching-substring rest 5))
 		(year (matching-substring rest 6)))
-	    (irchat-w-insert irchat-300-buffer (format "Last input received %s.\n" time))
+	    (irchat-w-insert irchat-300-buffer (format "%sLast input received %s.\n" irchat-info-prefix time))
 	    )
 	(message "IRCHAT: Strange 317 reply")))))
 
@@ -352,8 +363,8 @@ This is called if no specific handler exists"
 (defun irchat-count-words-from-string (str)
   "count words from a string"
   (let* ((len (- (length str) 1)) ; string is from [0,len[
-	 (i len) (seen nil) (words (if (= len 0) 0 1)))
-    (while (not (= i 0))
+	 (i len) (seen nil) (words (if (< len 0) 0 1)))
+    (while (not (< i 0))
       (progn
 	(if (string= (char-to-string (aref str i)) " ")
 	    (if seen
@@ -362,6 +373,9 @@ This is called if no specific handler exists"
 	(setq i (- i 1))))
     words))
 
+(defvar irchat-353-nameschnl nil "")
+(defvar irchat-353-nameslist "" "names list reply string")
+(defvar irchat-353-namescount 0 "")
 
 (defun irchat-handle-353-msg (prefix rest)
   "Handle the 353 (NAMREPLY) message.   If we are just polling the server,
@@ -372,20 +386,14 @@ don't display anything."
 	     (numusers (irchat-count-words-from-string users)))
 	(if (> irchat-polling 0)
 	    nil
-	  (irchat-w-insert (irchat-pick-buffer chnl)
-			   (format "%9s: (%d user%s): %s\n" 
-				   (if (string= chnl "*") "Priv" chnl)
-				   numusers 
-				   (cond 
-				    ((= numusers 0) "s")
-				    ((= numusers 1) "")
-				    (t "s"))
-				   users)))
+         (progn
+           (setq irchat-353-nameslist (concat irchat-353-nameslist users)
+                 irchat-353-nameschnl chnl
+                 irchat-353-namescount (+ irchat-353-namescount numusers))))
 	(irchat-scan-channels chnl)
 	(irchat-update-thischannel chnl users))
     (message "IRCHAT: Strange 353 message")))
 
-
 (defun irchat-handle-361-msg (prefix rest)
   "Handle the 361 KILLDONE."
   (if (string-match "[^ ]+ \\([^ ]+\\) +:\\(.*\\)" rest)
@@ -416,8 +424,21 @@ don't display anything."
 (defun irchat-handle-366-msg (prefix rest)
   "Handle the 366 ENDOFNAMES."
   (let ((level (- irchat-polling 1)))
-    (setq irchat-polling (if (< level 0) 0 level))))
-
+    (setq irchat-polling (if (< level 0) 0 level))
+    (irchat-w-insert (irchat-pick-buffer irchat-353-nameschnl)
+		     (format "%9s: (%d user%s): %s\n" 
+			     (if (string= irchat-353-nameschnl "*") 
+				 "Priv" 
+			       irchat-353-nameschnl)
+			     irchat-353-namescount
+			     (cond 
+			      ((= irchat-353-namescount 0) "s")
+			      ((= irchat-353-namescount 1) "")
+			      (t "s"))
+			     irchat-353-nameslist))
+    (setq irchat-353-nameslist nil
+	  irchat-353-nameschnl nil
+	  irchat-353-namescount 0)))
 
 (defun irchat-handle-367-msg (prefix rest)
   "Handle the 367 BAN."
@@ -483,4 +504,3 @@ don't display anything."
 ;;;
 ;;; eof
 ;;;
-
