@@ -1,13 +1,13 @@
+;;;  -*- emacs-lisp -*-
 ;;;
-;;; $Id: irchat-commands.el,v 1.1 1995/01/15 11:43:37 tmo Exp tmo $
+;;;  $Id: irchat-commands.el,v 1.7 1997/02/18 12:31:25 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile 
-  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines)
+(eval-when-compile (require 'irchat-inlines))
+(eval-and-compile  
   (require 'irchat-dcc)
-  (require 'gnus-caesar))
-
+  (require 'irchat-caesar))
 
 (defun irchat-Command-describe-briefly ()
   (message (substitute-command-keys "Type \\[describe-mode] for help")))
@@ -40,6 +40,7 @@
 		      (irchat-send "NAMES %s" (car channel))))
 	  irchat-channel-alist))
 
+
 (defun irchat-Command-find-timestamp ()
   (interactive)
   (save-excursion
@@ -82,6 +83,25 @@
 	    (substring s 11 16))))
 
 
+(defvar irchat-last-timestamp-time nil "Last time timestamp was inserted")
+(defvar irchat-last-timestamp-no-cons-p nil "Last timestamp was no-cons")
+
+
+(defun irchat-Command-timestamp-if-interval-expired (&optional no-cons)
+  (interactive)
+  (if (and (not (and no-cons
+		     irchat-last-timestamp-no-cons-p))
+	   (numberp irchat-timestamp-interval)
+	   (> irchat-timestamp-interval 0)
+	   (or (null irchat-last-timestamp-time)
+	       (> (irchat-time-difference irchat-last-timestamp-time
+					  (current-time))
+		  irchat-timestamp-interval)))
+      (progn
+	(irchat-Command-timestamp)
+	(setq irchat-last-timestamp-no-cons-p no-cons))))
+
+
 (defun irchat-Command-timestamp ()
   (interactive)
   (let ((stamp (format "%s" (format irchat-timestamp-format
@@ -89,7 +109,9 @@
 					(apply irchat-format-time-function
 					       (list (current-time-string)))
 				      (current-time-string))))))
-    (irchat-Dialogue-insert stamp)))
+    (let ((irchat-timestamp-interval 0))
+      (irchat-Dialogue-insert stamp)))
+  (setq irchat-last-timestamp-time (current-time)))
 
 
 (defun irchat-Command-send-message (message)
@@ -275,31 +297,43 @@ with specified user."
 
 
 (defun irchat-Command-kill (kill-nickname-var)
-  "Ignore messages from this user.  If already ignoring him/her, toggle."
-  (interactive (let (kill-nickname-var (completion-ignore-case t))
+  "Ignore messages from this user. Username can be given as case insensitive
+regular expression of form \".*@.*\.sub.domain\". 
+If already ignoring him/her, toggle.
+If variable irchat-variables-file is defined and the file is writable, its
+contents are updated future sessions."
+  (interactive (let ((kill-nickname-var nil) 
+		     (completion-ignore-case t))
 		 (setq kill-nickname-var 
-		       (completing-read 
-			"Ignore nickname: " 
+		       (completing-read "Ignore nickname or regexp: " 
 			irchat-nick-alist
 			'(lambda (s) t) nil nil))
 		 (list kill-nickname-var)))
+  ;; empty, just list them
   (if (string= "" kill-nickname-var)
       (let ((buf (current-buffer))
 	    (buffer-read-only))
-	(irchat-w-insert irchat-D-buffer "*** Currently ignored people:")
+	(set-buffer irchat-Dialogue-buffer)
+	(goto-char (point-max))
+	(irchat-w-insert irchat-D-buffer "*** Currently ignoring:")
 	(let ((mylist irchat-kill-nickname))
 	  (while mylist
 	    (irchat-w-insert irchat-D-buffer (format " %s" (car mylist)))
 	    (setq mylist (cdr mylist))))
 	(irchat-w-insert irchat-D-buffer "\n")
-	(set-buffer buf)))
-  (if (memq (intern kill-nickname-var irchat-obarray) irchat-kill-nickname)
-      (setq irchat-kill-nickname 
-	    (delq (intern kill-nickname-var irchat-obarray) 
-		  irchat-kill-nickname))
-    (setq irchat-kill-nickname 
-	  (cons (intern kill-nickname-var irchat-obarray) 
-		irchat-kill-nickname))))
+	(set-buffer buf))
+    ;; else not empty, check if exists
+    (let ((done nil) (elem irchat-kill-nickname))
+      (while (and elem (not done))
+	(if (string-ci-equal (car elem) kill-nickname-var)
+	    (setq irchat-kill-nickname (delete (car elem) irchat-kill-nickname)
+		  done t)
+	  (setq elem (cdr elem))))
+      ;; did not find, add to ignored ones
+      (if (not done)
+	  (setq irchat-kill-nickname (cons kill-nickname-var
+					   irchat-kill-nickname)))
+      (irchat-Command-save-vars))))
 
 
 (defun irchat-Command-send-action (&optional private)
@@ -612,8 +646,8 @@ be a string to send NICK upon entering."
 		  (irchat-send "QUIT :%s" quit-string))
 	      (irchat-send "QUIT :%s" (or irchat-signoff-msg ""))))
 	(irchat-clear-system)
-	(if irchat-timestamp-timer 
-	    (irchat-cancel-timer irchat-timestamp-timer))
+;	(if irchat-timestamp-timer 
+;	    (irchat-cancel-timer irchat-timestamp-timer))
 	(if irchat-names-timer 
 	    (irchat-cancel-timer irchat-names-timer))
 	(if irchat-use-full-window
@@ -724,6 +758,19 @@ be sent to the server.  For a list of messages, see irchat-Command-generic."
 	       client-clientinfo-nick-var irchat-query-client-clientinfo))
 
 
+(defun irchat-Command-client-x-face (client-x-face-nick-var)
+  "Ask about someones client x-face."
+  (interactive (let (client-x-face-nick-var (completion-ignore-case t))
+		 (setq client-x-face-nick-var 
+		       (irchat-completing-default-read 
+			"Whose client: " irchat-nick-alist
+			'(lambda (s) t) nil irchat-query-client-nick))
+		 (list client-x-face-nick-var)))
+  (setq irchat-query-client-nick client-x-face-nick-var)
+  (irchat-send "PRIVMSG %s :%s"
+	       client-x-face-nick-var irchat-query-client-x-face))
+
+
 (defun irchat-Command-client-generic (client-generic-nick-var)
   "Ask about someones client clientinfo."
   (interactive (let (client-generic-nick-var (completion-ignore-case t))
@@ -766,6 +813,26 @@ be sent to the server.  For a list of messages, see irchat-Command-generic."
     (irchat-next-line 1)))
 
 
+(defun irchat-Command-client-x-face-from-minibuffer ()
+  "Ask about someones client clientinfo."
+  (interactive)
+  (setq irchat-client-x-face
+	(read-from-minibuffer "New X-Face: "
+			      irchat-client-x-face)))
+
+
+(defun irchat-Command-client-x-face-from-commandbuffer ()
+  "Ask about someones client clientinfo."
+  (interactive)
+  (let (start stop)
+    (beginning-of-line)
+    (setq start (point))
+    (end-of-line)
+    (setq stop (point))
+    (setq irchat-client-x-face (buffer-substring start stop))
+    (irchat-next-line 1)))
+
+
 (defun irchat-Command-client-ping (client-help-nick-var)
   "Ask about someones client help."
   (interactive (let (client-help-nick-var (completion-ignore-case t))
@@ -834,7 +901,7 @@ be sent to the server.  For a list of messages, see irchat-Command-generic."
   (beginning-of-line nil)
   (push-mark (point))
   (end-of-line)
-  (gnus-caesar-region n))
+  (irchat-caesar-region n))
 
 ;;;
 ;;;
@@ -869,10 +936,59 @@ be sent to the server.  For a list of messages, see irchat-Command-generic."
   (interactive)
   (let ((file (expand-file-name irchat-variables-file)))
     (if (file-exists-p file)
-	(progn
+	(let ((nick irchat-nickname))
 	  (load-file file)
+	  (setq irchat-nickname nick)
 	  (irchat-Command-reconfigure-windows)))))
 
+(defun irchat-Command-save-vars ()
+  (interactive)
+  (let ((output-buffer (find-file-noselect
+                        (expand-file-name irchat-variables-file)))
+	output-marker)
+    (save-excursion
+      (set-buffer output-buffer)
+      (goto-char (point-min))
+      (if (re-search-forward "^;; Saved Settings *\n" nil 'move)
+          (let ((p (match-beginning 0)))
+            (goto-char p)
+            (or (re-search-forward "^;; End of Saved Settings *\\(\n\\|\\'\\)"
+				   nil t)
+                (error (format 
+			"can't find END of saved state in %s" 
+			irchat-variables-file)))
+	    (delete-region p (match-end 0)))
+        (goto-char (point-max))
+        (insert "\n"))
+      (setq output-marker (point-marker))
+      (let ((print-readably t) 
+	    (print-escape-newlines t)
+            (standard-output output-marker))
+        (princ ";; Saved Settings\n")
+        (mapcar (function 
+		 (lambda (var)
+		   (if (symbolp var)
+		       (prin1 (list 'setq var
+				    (let ((val (symbol-value var)))
+				      (if (memq val '(t nil))
+					  val
+					(list 'quote val)))))
+		     (setq var (eval var))
+		     (cond ((eq (car-safe var) 'progn)
+			    (while (setq var (cdr var))
+			      (prin1 (car var))
+			      (princ "\n")
+			      (if (cdr var) (princ "  "))))
+			   (var
+			    (prin1 "xx")(prin1 var))))
+		   (if var (princ "\n"))))
+                irchat-saved-forms)
+        (princ "\n")
+        (princ ";; End of Saved Settings\n")))
+    (set-marker output-marker nil)
+    (save-excursion
+      (set-buffer output-buffer)
+      (save-buffer))))
 
 (defun irchat-Command-reconfigure-windows ()
   (interactive)
