@@ -1,10 +1,10 @@
+;;;  -*- emacs-lisp -*-
 ;;;
-;;; $Id: irchat-filter.el,v 1.1 1995/01/15 11:43:37 tmo Exp $
+;;;  $Id: irchat-filter.el,v 1.3 1997/02/18 12:31:25 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile
-  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines))
+(eval-when-compile (require 'irchat-inlines))
 
 ;;;
 ;;;  These are defsubst just for speed, as it is expensive to call funtions at
@@ -12,7 +12,7 @@
 ;;;
 (defsubst irchat-handle-msg-msg (prefix rest)
   (if (or (and prefix
-	       (memq (intern prefix irchat-obarray) irchat-kill-nickname)
+	       (irchat-ignore-this-p prefix irchat-userathost)
 	       (irchat-msg-from-ignored prefix rest))
 	  (and (not prefix)
 	       (string= "> " rest)))
@@ -45,40 +45,67 @@
 	      (beep t))))
     ))
 
+(defun irchat-run-message-hook-types (hook prefix rest-of-line)
+  "Run either old fashion irchat hook variable or hook list."
+  (let ((hook (if (and (symbolp hook)
+		       (boundp hook)
+		       (not (fboundp hook)))
+		  (eval hook)
+		hook)))
+    (if (or (and (symbolp hook)
+		 (fboundp hook))
+	    (and (listp hook)
+		 (eq (car hook) 'lambda)))
+	(eval (list hook prefix rest-of-line))
+      (if (listp hook)
+	  (let ((hooks hook)
+		(r nil))
+	    (while hooks
+	      (if (irchat-run-message-hook-types (car hooks)
+						 prefix 
+						 rest-of-line)
+		  (progn
+		    (setq hooks '())
+		    (setq r t))
+		(setq hooks (cdr hooks))))
+	    r)
+	nil))))
 
 (defsubst irchat-handle-message-2 (prefix message rest-of-line)
   "Helper function (actually a macro) for irchat-handle-message."
   (let ((hook (intern (concat "irchat-" message "-hook")))
+	(after-hook (intern (concat "irchat-after-" message "-hook")))
 	buffer-read-only fun)
-    (if (and (boundp hook)
-	     (eval hook)
-	     (eval (list (eval hook) prefix rest-of-line)))
+    (if (irchat-run-message-hook-types hook prefix rest-of-line)
 	;; If we have a hook, and it returns T, do nothing more
 	nil
       ;; else call the handler
 
-      (if (string= message "msg")
-	  (irchat-handle-msg-msg prefix rest-of-line)
+      (progn
+	(if (string= message "msg")
+	    (irchat-handle-msg-msg prefix rest-of-line)
 	    
-	(if (fboundp (setq fun (intern
-				(concat "irchat-handle-" message "-msg"))))
-	  (progn
-	    (apply fun (list prefix rest-of-line)))
-	  (let* ((message-number (string-to-int message))
-		 (default-number (/ message-number 100)))
-	    (if (and (> message-number 0)
-		     (fboundp (setq fun (intern
-					 (concat "irchat-handle-"
-						 (format "%d00" default-number)
-						 "-msgs")))))
-		(progn
-		  (apply fun (list message-number prefix rest-of-line)))
-	      (message "IRCHAT: Unknown IRC message \":%s %s %s\"" prefix
-		       (upcase message) rest-of-line)
-	      (irchat-w-insert irchat-D-buffer 
-			       (format "MESSAGE: %s, %s, %s\n" 
-				       prefix message rest-of-line))
-	      )))))))
+	  (if (fboundp (setq fun (intern
+				  (concat "irchat-handle-" message "-msg"))))
+	      (progn
+		(apply fun (list prefix rest-of-line)))
+	    (let* ((message-number (string-to-int message))
+		   (default-number (/ message-number 100)))
+	      (if (and (> message-number 0)
+		       (fboundp (setq fun (intern
+					   (concat "irchat-handle-"
+						   (format "%d00" 
+							   default-number)
+						   "-msgs")))))
+		  (progn
+		    (apply fun (list message-number prefix rest-of-line)))
+		(message "IRCHAT: Unknown IRC message \":%s %s %s\"" prefix
+			 (upcase message) rest-of-line)
+		(irchat-w-insert irchat-D-buffer 
+				 (format "MESSAGE: %s, %s, %s\n" 
+					 prefix message rest-of-line))
+		))))
+	(irchat-run-message-hook-types after-hook prefix rest-of-line)))))
 
 
 (defsubst irchat-handle-message ()
@@ -149,7 +176,7 @@
 	(let* ((i (car conv-list)) (f (car i)) (s (car (cdr i)))
 	       (s1 (if (stringp f) f (funcall f output)))
 	       (s2 (if (stringp s) s (funcall s s1))))
-	  (setq output (replace-in-string output s1 s2)
+	  (setq output (irchat-replace-in-string output s1 s2)
 		conv-list (cdr conv-list)))))
 
     (insert output)
@@ -182,7 +209,7 @@
 	(irchat))
     (message "IRCHAT: Connection closed.")))
 
-(provide 'irchat-filter)
+(eval-and-compile (provide 'irchat-filter))
 ;;;
 ;;; eof
 ;;;
