@@ -1,9 +1,11 @@
-;;; $Id: irchat-handle.el,v 1.1 1995/01/15 11:43:37 tmo Exp $
+;;;  -*- emacs-lisp -*-
+;;;
+;;;  $Id: irchat-handle.el,v 1.6 1997/02/18 12:31:25 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright in(eval-wfo
 
-(eval-when-compile
-  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines)
+(eval-when-compile (require 'irchat-inlines))
+(eval-and-compile  
   (require 'irchat-filter))
 
 (defun irchat-handle-error-msg (prefix rest)
@@ -97,11 +99,13 @@
 	    (string-match "^\\([^ ]*\\) :\\(.*\\)" rest)
 	    (irchat-w-insert irchat-D-buffer 
 			     (format "%s%s\n"
-				     irchat-notice-prefix (matching-substring rest 2))))))))
+				     irchat-notice-prefix 
+				     (matching-substring rest 2))))))))
 
 
 (defun irchat-handle-ping-msg (prefix rest)
   (irchat-send "PONG yourself")
+  (irchat-Command-timestamp-if-interval-expired t)
   (irchat-maybe-poll))
 
 
@@ -111,7 +115,7 @@
 
 (defun irchat-handle-privmsg-msg (prefix rest)
   (if (and prefix
-	   (memq (intern prefix irchat-obarray) irchat-kill-nickname)
+	   (irchat-ignore-this-p prefix irchat-userathost)
 	   (irchat-msg-from-ignored prefix rest))
       nil
     (if (and (string-match "\007" rest) irchat-beep-on-bells)
@@ -166,7 +170,7 @@
 ;; NOTICE
 (defun irchat-handle-privmsglike-msg (prefix rest)
   (if (and prefix
-	   (memq (intern prefix irchat-obarray) irchat-kill-nickname)
+	   (irchat-ignore-this-p prefix irchat-userathost)
 	   (irchat-msg-from-ignored prefix rest))
       nil
     (string-match "^\\([^ ]+\\) :\\(.*\\)" rest)
@@ -290,17 +294,17 @@
 
 (defun irchat-handle-kick-msg (prefix rest)
   "Handle the KICK message."
-  (if (string-match "^\\([^ ]*\\) \\([^ ]*\\)" rest)
+  (if (string-match "^\\([^ ]*\\) \\([^ ]*\\) *:\\(.*$\\)" rest)
       (let ((match1 (matching-substring rest 1))
-	    (match2 (matching-substring rest 2)))
+	    (match2 (matching-substring rest 2))
+	    (match3 (matching-substring rest 3)))
 	(if (string= match2 irchat-nickname)
 	  (progn
 	    (irchat-w-insert (irchat-pick-buffer match1)
-			     (format "%sYou were kicked off channel %s by %s.\n" 
-				     irchat-change-prefix match1 prefix))
+			     (format "%sYou were kicked off channel %s by %s (%s).\n" irchat-change-prefix match1 prefix match3))
 	    (setq 
-	     irchat-current-channels (string-list-ci-delete irchat-current-channel 
-							    irchat-current-channels)
+	     irchat-current-channels 
+	           (string-list-ci-delete match1 irchat-current-channels)
 	     irchat-current-channel (car irchat-current-channels)
 	     irchat-channel-indicator (if irchat-current-channel 
 					  (format "Channel %s" 
@@ -364,6 +368,8 @@
 
 
 (defun irchat-handle-part-msg (prefix rest) ; kmk, 14101990
+  (if (string-match "\\([^ ]*\\)\ .*" rest)
+      (setq rest (matching-substring rest 1))) ;; throw away user given info.
   (if (string= prefix irchat-nickname)
       (setq irchat-current-channels
 	    (string-list-ci-delete rest irchat-current-channels)
@@ -388,7 +394,7 @@
   (let ((mylist irchat-buffer-preferences)
 	(found nil)
 	(result nil))
-    (while (and (not found) mylist)
+    (while (and chnl (not found) mylist)
       (if (string-match (car (car mylist)) chnl)
 	  (setq result (car (cdr (car mylist)))
 		found t))
