@@ -1,14 +1,13 @@
+;;;  -*- emacs-lisp -*-
 ;;;
-;;; $Id: irchat-main.el,v 1.1 1995/01/15 11:43:37 tmo Exp tmo $
+;;;  $Id: irchat-main.el,v 1.8 1997/02/18 12:31:25 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile
-  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines)
+(eval-when-compile (require 'irchat-inlines))
+(eval-and-compile  
   (require 'irchat-filter))
 
-(provide 'irchat)
-
 (if irchat-want-traditional
     (defvar irchat-command-window-on-top nil
       "*If non-nil, the Command window will be put at the top of the screen.
@@ -43,6 +42,16 @@ Else it is put at the bottom."))
 			       "\" is received.
 The hook function is called with two arguments, PREFIX and REST-OF-LINE.
 It should return non NIL if no further processing of the message is to be
+carried out.")))
+	   (eval (list 'defvar (intern (concat "irchat-after-"
+					       (prin1-to-string sym)
+					       "-hook"))
+		       nil
+		       (concat "*A hook that is executed after the IRC "
+			       "message \"" (upcase (prin1-to-string sym))
+			       "\" has been received and handled.
+The hook function is called with two arguments, PREFIX and REST-OF-LINE.
+It should return non NIL if no further processing of the hook is to be
 carried out.")))))
 	irchat-msg-list)
 
@@ -60,6 +69,9 @@ carried out.")))))
     ("c" 	irchat-Command-client-clientinfo)
     ("g" 	irchat-Command-client-generic)
     ("p" 	irchat-Command-client-ping)
+    ("x" 	irchat-Command-client-x-face)
+    ("X" 	irchat-Command-client-x-face-from-minibuffer)
+    ("\C-x" 	irchat-Command-client-x-face-from-commandbuffer)
     ("U" 	irchat-Command-client-userinfo-from-minibuffer)
     ("\C-u" 	irchat-Command-client-userinfo-from-commandbuffer))
   "Key definition table for Client-query-map")
@@ -77,6 +89,7 @@ carried out.")))))
     ("i" 	irchat-Command-invite)
     ("j" 	irchat-Command-join)
     ("l" 	irchat-Command-load-vars)
+    ("s" 	irchat-Command-save-vars)
     ("m" 	irchat-Dialogue-enter-message)
     ("n" 	irchat-Command-names)
     ("o" 	other-window)
@@ -123,6 +136,7 @@ carried out.")))))
     ("\C-c\C-k" irchat-Command-kick)
     ("\C-cl" 	irchat-Command-list)
     ("\C-cL" 	irchat-Command-load-vars)
+    ("\C-cS" 	irchat-Command-save-vars)
     ("\C-cm" 	irchat-Command-message)
     ("\C-c\C-m" irchat-Command-modec)
     ("\C-cn" 	irchat-Command-nickname)
@@ -235,8 +249,9 @@ If optional argument SERVICE is non-nil, open by the service name."
 	   (setq irchat-old-nickname irchat-nickname)
 	   (setq irchat-nick-accepted 'sent)
 	   (irchat-send "NICK %s" irchat-nickname)
-	   (irchat-send "PING %s" host)
-	   (if (setq status (irchat-wait-for-response ".*PONG.*"))
+	   ; (irchat-send "PING %s" host)
+	   (setq status t)
+	   (if (setq status (irchat-wait-for-response ".*"))
 	       (progn
 		 (set-process-sentinel irchat-server-process
 				       'irchat-sentinel)
@@ -304,10 +319,10 @@ If the stream is opened, return T, otherwise return NIL."
 
 (defvar irchat-timers
   (list
-   (list nil (function irchat-Command-timestamp) irchat-timestamp-interval)
+   ;(list nil (function irchat-Command-timestamp) irchat-timestamp-interval)
    (list nil (function irchat-Command-pollnames) irchat-pollnames-interval)
    (list nil (function irchat-Command-keepalive) irchat-keepalive-interval)
-   (list nil (function irchat-check-buffers) irchat-checkbuffer-interval)
+   ;(list nil (function irchat-check-buffers) irchat-checkbuffer-interval)
    )
   "Symbol name to store timer, timer-function and timer-interval.")
 
@@ -625,6 +640,11 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	   (spoint nil)
 	   (oldwstart nil)
 	   (oldwpoint nil))
+      ;;
+      ;; Check buffers and possibly insert timestamp.
+      ;;
+      (irchat-check-buffers-if-interval-expired)
+      (irchat-Command-timestamp-if-interval-expired)
 
       (if (not nbuf)
 	  (save-excursion
@@ -660,9 +680,9 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	    (progn
 	      (goto-char (point-max))
 	      (vertical-motion (- (+ 1 (if (not irchat-scroll-step)
-					   (/ (window-height win) 2)
-					 irchat-scroll-step))
-				  (window-height win))
+					   (/ (irchat-window-height win) 2)
+					 (1- irchat-scroll-step)))
+				  (irchat-window-height win))
 			       win)
 	      (set-window-start win (point))
 	      (goto-char (point-max)))))
@@ -672,8 +692,7 @@ One is for entering commands and text, the other displays the IRC dialogue."
 	    (set-window-start (get-buffer-window obuf) oldwstart)
 	    (set-window-point (get-buffer-window obuf) oldwpoint)
 	    (goto-char oldwpoint)
-	    )))
-    nil))
+	    )))))
 
 
 (defun irchat-get-buffer-create (name)
@@ -719,19 +738,38 @@ One is for entering commands and text, the other displays the IRC dialogue."
     buffer-ownfrozen))
 
 
+(defvar irchat-last-checkbuffer-time nil "Last time buffers were checked.")
+
+
+(defun irchat-check-buffers-if-interval-expired ()
+  (if (and (numberp irchat-checkbuffer-interval)
+           (> irchat-checkbuffer-interval 0)
+           (or (null irchat-last-checkbuffer-time)
+               (> (irchat-time-difference irchat-last-checkbuffer-time
+                                          (current-time))
+                  irchat-checkbuffer-interval)))
+      (progn
+        (irchat-check-buffers)
+        t)
+    nil))
+
+
 (defun irchat-check-buffers ()
-  (if (> irchat-buffer-maxsize 0)
-      (let ((buflist irchat-buffer-list)
-	    (obuf (current-buffer)))
-	(while buflist
-	  (set-buffer (irchat-get-buffer-create (car buflist)))
-	  (if (< irchat-buffer-maxsize (buffer-size))
-	      (let ((buffer-read-only nil))
-		(goto-char (- (buffer-size) irchat-buffer-defsize))
-		(forward-line -1)
-		(delete-region (point-min) (point))))
-	  (setq buflist (cdr buflist)))
-	(set-buffer obuf))))
+  (let ((irchat-checkbuffer-interval 0))
+    (if (> irchat-buffer-maxsize 0)
+	(let ((buflist irchat-buffer-list)
+	      (obuf (current-buffer)))
+	  (while buflist
+	    (set-buffer (irchat-get-buffer-create (car buflist)))
+	    (if (< irchat-buffer-maxsize (buffer-size))
+		(let ((buffer-read-only nil))
+		  (goto-char (- (buffer-size) irchat-buffer-defsize))
+		  (forward-line -1)
+		  (delete-region (point-min) (point))))
+	    (setq buflist (cdr buflist)))
+	  (set-buffer obuf))))
+  (setq irchat-last-checkbuffer-time (current-time)))
+
 
 (defun irchat-is-message-ignored (string buffer)
   (let ((mylist irchat-ignore-list)
@@ -777,6 +815,7 @@ One is for entering commands and text, the other displays the IRC dialogue."
     )
   )
 
+(eval-and-compile (provide 'irchat))
 ;;;
 ;;; eof
 ;;;
