@@ -1,54 +1,26 @@
-;;; $Id: irchat-misc.el,v 1.1 1995/01/15 11:43:37 tmo Exp tmo $
+;;;  -*- emacs-lisp -*-
+;;;
+;;;  $Id: irchat-misc.el,v 1.4 1997/02/18 12:31:25 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
-(eval-when-compile
-  (require 'irchat-globals)  (require 'irchat-vars)  (require 'irchat-inlines)
+(eval-when-compile (require 'irchat-inlines))
+(eval-and-compile  
   (require 'irchat-filter))
 
-;;; not used (see irchat-Privmsg-buffer definition too) //too
-;;;
-;;;(defun irchat-get-typed-buffer (type)
-;;;  (cond 
-;;;   ;; private messages and notices
-;;;   ((and (eq type irchat-privmsg)
-;;;	 irchat-Privmsg-buffer)
-;;;    (irchat-get-buffer-create irchat-Privmsg-buffer))
-;;;   ;; the rest goes to dialogue
-;;;   (t
-;;;    (get-buffer irchat-Dialogue-buffer))))
-;;;
-;;;
-;;;(defun irchat-insert (type &rest message)
-;;;  (let ((tgtbuffer (irchat-get-typed-buffer type))
-;;;	(oldbuffer (current-buffer)))
-;;;    (set-buffer tgtbuffer)
-;;;    (let (buffer-read-only)
-;;;      (and message 
-;;;	   (mapcar 
-;;;	    (function (lambda (part) 
-;;;			(irchat-w-insert (buffer-name) part)))
-;;;	    message)))
-;;;    (set-buffer oldbuffer)))
-;;;
-;;;
-;;;(defun irchat-newline (type &optional nlines)
-;;;  (let ((tgtbuffer (irchat-get-typed-buffer type))
-;;;	(oldbuffer (current-buffer)))
-;;;    (set-buffer tgtbuffer)
-;;;    (let (buffer-read-only)
-;;;      (newline nlines))
-;;;    (set-buffer oldbuffer)))
-;;; <///too>
+(defun irchat-ignore-this-p (nick uah)
+  (let ((killit nil))
+    (mapcar (function 
+	     (lambda (kill)
+	       (if (string-match kill nick)
+		   (setq killit t)))) irchat-kill-nickname)
+    (if (not killit)
+	(mapcar (function 
+		 (lambda (kill)
+		   (if (string-match kill uah)
+		       (setq killit t)))) irchat-kill-nickname))
+    killit))
 
-;;(defun irchat-own-message (message)
-;;  (let ((obuf (current-buffer)))
-;;    (set-buffer irchat-Dialogue-buffer)
-;;    (let (buffer-read-only)
-;;      (goto-char (point-max))
-;;      (irchat-handle-msg-msg nil message))
-;;    (set-window-point (irchat-get-buffer-window irchat-Dialogue-buffer)
-;;		      (point-max))))
 (defun irchat-own-message (message)
   (irchat-w-insert (irchat-pick-buffer irchat-current-channel)
 		   (format "%s\n" message))
@@ -66,7 +38,7 @@
   (let ((item (apply 'format args)) ditem)
     (let ((conv-list irchat-send-convert-list))
       (while conv-list
-	(setq item (replace-in-string item (car (car conv-list))
+	(setq item (irchat-replace-in-string item (car (car conv-list))
 				      (car (cdr (car conv-list)))))
 	(setq conv-list (cdr conv-list))))
     (process-send-string irchat-server-process
@@ -88,16 +60,21 @@
       (store-match-data data))))
 
 
-(defun replace-in-string (string from to)
-  (let ((newstring "")
-	(pos 0))
-    (while (string-match from string pos)
-      (setq newstring (concat newstring
-			      (substring string pos (match-beginning 0))
-			      to))
-      (setq pos (match-end 0)))
-    (concat newstring (substring string pos (length string)))))
-
+(defun irchat-replace-in-string (string from to)
+  (if (string-match "XEmacs" emacs-version)
+      (replace-in-string str regexp newtext t)
+    (save-excursion
+      (let ((buf (get-buffer-create "*replace-in-string*")) res)
+        (set-buffer buf)
+        (erase-buffer)
+        (insert str)
+        (goto-char (point-min))
+        (while (re-search-forward regexp nil t)
+          (replace-match newtext t t))
+        (setq res (buffer-substring-no-properties (point-min) (point-max)))
+        (kill-buffer buf)
+        res)
+      )))
 
 (defun irchat-scroll-if-visible (window)
   (if window (set-window-point window (point-max))))
@@ -185,6 +162,16 @@
       (irchat-w-insert irchat-I-buffer (format "%s::%s\n" prefix rest))
       t)))
 
+(defun irchat-window-height (win)   ;;; No w-v-h in GNU-Emacs //tri
+  "Get the visible window height portably with GNU-Emacs and XEmacs." 
+  (if (fboundp 'window-displayed-height)
+      (window-displayed-height win)
+    (window-height win)))
+
+(defun irchat-time-difference (t0 t1)
+  "Difference in seconds of two `three integer lists' returned by current-time function."
+  (+ (* (- (car t1) (car t0)) 65536) (- (car (cdr t1)) (car (cdr t0)))))
+
 ;;;
 ;;; eof
 ;;;
