@@ -1,4 +1,6 @@
-;;; $Id: irchat-timer.el,v 1.1 1995/01/15 11:43:37 tmo Exp $
+;;;  -*- emacs-lisp -*-
+;;;
+;;;  $Id: irchat-timer.el,v 1.2 1997/02/18 12:31:25 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
@@ -17,14 +19,14 @@
       (progn
 	(defun irchat-cancel-timer (timer)
 	  "Cancel timer."
-	  (delete-timer timer))
+	  (delete-itimer timer))
 	(defun irchat-start-timer (function interval)
 	  "Add timer function."
 	  (interactive)
 	  (if interval
 	      (start-itimer "IRCHAT" function interval interval))))
     (progn
-;;      (eval-when-compile
+;;      (eval-and-compile
 ;;	(require 'timer))
       (defun irchat-cancel-timer (timer)
 	"Cancel timer."
@@ -44,4 +46,3 @@
 ;;;
 ;;; eof
 ;;;
-
