@@ -1,5 +1,6 @@
+;;;  -*- emacs-lisp -*-
 ;;;
-;;; $Id: irchat-vars.el,v 1.1 1995/01/15 11:43:37 tmo Exp tmo $
+;;;  $Id: irchat-vars.el,v 1.9 1997/02/21 12:55:24 too Exp $
 ;;;
 ;;; see file irchat-copyright.el for change log and copyright info
 
@@ -7,6 +8,15 @@
 ;;; user modifiable variables
 ;;;
 
+(defvar irchat-saved-forms 
+  (purecopy '(irchat-kill-nickname
+	      irchat-compress-changes
+	      irchat-timestamp-interval
+	      irchat-use-full-window
+	      irchat-command-window-on-top
+	      irchat-beep-on-bells))
+  "*Variables whose values are saved via command irchat-Command-save-vars")
+
 (defvar irchat-command-window-height 5
   "*How large should Command window be on startup.")
 
@@ -76,7 +86,21 @@ killed again if automagic reconnect is too fast.")
 ;;;
 ;;;  DCC
 ;;;
-(defvar irchat-dcc-program "dcc"
+(defvar irchat-dcc-program
+;;; set dcc program as "dcc", "dcc.perl" or nil, depending which binary found.
+;;; current version takes the one which is earlier in path (if many).
+  (let* ((result nil) 
+	 (list exec-path)
+	 (path (car list)))
+    (while (and path (not result))
+      (setq path (file-name-as-directory path))
+      (if (file-executable-p (concat path "dcc")) (setq result "dcc")
+	(if (file-executable-p (concat path "dcc.perl")) (setq result "dcc.perl")
+	  ))
+      (setq list (cdr list)
+	    path (car list))
+      )
+    result)
   "*Name of the external dcc-program.")
 
 (defvar irchat-dcc-directory "~/tmp" 
@@ -125,6 +149,9 @@ IRCHAT to suit old users of the irc-loser-client.")
 (defvar irchat-wallops-prefix "*** Notice: "
   "*String to add before any WALLOPS message")
 
+(defvar irchat-info-prefix ""
+  "*String to add before any informational message")
+
 ;;;
 ;;;  Buffers
 ;;;
@@ -191,6 +218,9 @@ Default is what (system-name) returns.")
 (defvar irchat-client-userinfo "No user information given."
   "*Userinfo message given to anyone asking.")
 
+(defvar irchat-client-x-face ""
+  "*X-Face message given to anyone asking.  Proper form is \"X-Face: ....\".")
+
 (defvar irchat-keepalive-interval nil
   "*Interval on seconds the existence of server connection is checked")
 
@@ -305,7 +335,7 @@ The last ignores all messages that contain the word `fuck`.
   "*Maximum size (in bytes) of any irchat buffer.")
 (defvar irchat-buffer-defsize 900000
   "*Size to shrink buffer if it grows too big.")
-(defvar irchat-checkbuffer-interval 120
+(defvar irchat-checkbuffer-interval (* 60 10)
   "*Interval between buffer-size checks.")
 
 (defvar irchat-private-window-height 5
@@ -343,7 +373,7 @@ would cause messages from and to channel #report to be displayed on
 buffer named *report-buffer* and all other messages are displayed on
 Dialogue-buffer.")
 
-(provide 'irchat-vars)
+(eval-and-compile (provide 'irchat-vars))
 ;;;
 ;;; eof
 ;;;
